==> foundation-2.6.1.tgz: package/PageExportDoc/PageExportDoc.esm.js <==
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export const PageExportDoc = /*#__PURE__*/React.forwardRef((props, ref) => {
  const attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, Object.assign({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M94.284 65.553L75.825 52.411a1.255 1.255 0 00-1.312-.093c-.424.218-.684.694-.685 1.173l.009 6.221H57.231c-.706 0-1.391.497-1.391 1.204v11.442c0 .707.685 1.194 1.391 1.194h16.774v6.27c0 .478.184.917.609 1.136.425.219.853.182 1.242-.097l18.432-13.228c.335-.239.477-.626.477-1.038v-.002c0-.414-.144-.8-.481-1.04z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M64.06 78.553h-6.49a1.73 1.73 0 00-1.73 1.73h-.007v3.01H15.191V36.16h17.723a1.73 1.73 0 001.73-1.73V16.707h21.188v36.356h.011a1.728 1.728 0 001.726 1.691h6.49c.943 0 1.705-.754 1.726-1.691h.004V12.5h-.005V8.48a1.73 1.73 0 00-1.73-1.73h-32.87L5.235 32.7v58.819c0 .956.774 1.73 1.73 1.73h57.089a1.73 1.73 0 001.73-1.73v-2.448h.005v-8.79a1.729 1.729 0 00-1.729-1.728z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M20.364 61.862v9.231h4.138c2.893 0 5.052-1.675 5.052-4.623s-2.159-4.608-5.065-4.608h-4.125zm6.352 4.609c0 1.163-.83 2.187-2.228 2.187H23.16v-4.36h1.342c1.495 0 2.214.927 2.214 2.173zm4.017.014c0 2.837 2.201 4.774 5.052 4.774 2.851 0 5.051-1.938 5.051-4.774 0-2.837-2.201-4.775-5.051-4.775-2.852 0-5.052 1.937-5.052 4.775zm7.266 0c0 1.287-.872 2.311-2.214 2.311-1.343 0-2.214-1.024-2.214-2.311s.872-2.312 2.214-2.312 2.214 1.025 2.214 2.312zm9.094-2.312c.831 0 1.55.623 1.786 1.342l2.408-1.121c-.554-1.273-1.771-2.685-4.194-2.685-2.892 0-5.079 1.924-5.079 4.775 0 2.837 2.187 4.774 5.079 4.774 2.422 0 3.654-1.467 4.194-2.699l-2.408-1.107c-.235.719-.955 1.342-1.786 1.342-1.342 0-2.242-1.024-2.242-2.311s.9-2.31 2.242-2.31z"
  }));
});
PageExportDoc.displayName = 'PageExportDoc';
export const PageExportDocDimensions = {
  height: 100,
  width: 100
};

==> foundation-2.7.1.tgz: package/PageExportDoc/PageExportDoc.esm.js <==
import _extends from "@babel/runtime/helpers/extends";
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export var PageExportDoc = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, _extends({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M94.284 65.553L75.825 52.411a1.255 1.255 0 00-1.312-.093c-.424.218-.684.694-.685 1.173l.009 6.221H57.231c-.706 0-1.391.497-1.391 1.204v11.442c0 .707.685 1.194 1.391 1.194h16.774v6.27c0 .478.184.917.609 1.136.425.219.853.182 1.242-.097l18.432-13.228c.335-.239.477-.626.477-1.038v-.002c0-.414-.144-.8-.481-1.04z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M64.06 78.553h-6.49a1.73 1.73 0 00-1.73 1.73h-.007v3.01H15.191V36.16h17.723a1.73 1.73 0 001.73-1.73V16.707h21.188v36.356h.011a1.728 1.728 0 001.726 1.691h6.49c.943 0 1.705-.754 1.726-1.691h.004V12.5h-.005V8.48a1.73 1.73 0 00-1.73-1.73h-32.87L5.235 32.7v58.819c0 .956.774 1.73 1.73 1.73h57.089a1.73 1.73 0 001.73-1.73v-2.448h.005v-8.79a1.729 1.729 0 00-1.729-1.728z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M20.364 61.862v9.231h4.138c2.893 0 5.052-1.675 5.052-4.623s-2.159-4.608-5.065-4.608h-4.125zm6.352 4.609c0 1.163-.83 2.187-2.228 2.187H23.16v-4.36h1.342c1.495 0 2.214.927 2.214 2.173zm4.017.014c0 2.837 2.201 4.774 5.052 4.774 2.851 0 5.051-1.938 5.051-4.774 0-2.837-2.201-4.775-5.051-4.775-2.852 0-5.052 1.937-5.052 4.775zm7.266 0c0 1.287-.872 2.311-2.214 2.311-1.343 0-2.214-1.024-2.214-2.311s.872-2.312 2.214-2.312 2.214 1.025 2.214 2.312zm9.094-2.312c.831 0 1.55.623 1.786 1.342l2.408-1.121c-.554-1.273-1.771-2.685-4.194-2.685-2.892 0-5.079 1.924-5.079 4.775 0 2.837 2.187 4.774 5.079 4.774 2.422 0 3.654-1.467 4.194-2.699l-2.408-1.107c-.235.719-.955 1.342-1.786 1.342-1.342 0-2.242-1.024-2.242-2.311s.9-2.31 2.242-2.31z"
  }));
});
PageExportDoc.displayName = 'PageExportDoc';
export var PageExportDocDimensions = {
  height: 100,
  width: 100
};
